from setuptools import setup, find_packages

setup(
    name='uuid_shortener',
    version='0.1.2',
    description='A utility to shorten UUIDs using base62 encoding.',
    author='Sammeow Chan',
    author_email='1010hk@gmail.com',
    url='https://github.com/sammeowww/py_uuid_shortener',  # Git repository URL
    package_dir={'': 'src'},
    packages=find_packages(where='src'),
    install_requires=[],
    license='MIT',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',  # Added Python 3.12 support
    ],
    keywords='uuid shortener base62',
)




import uuid
import string

class UUIDShortener:
    alphabet = string.digits + string.ascii_letters

    @staticmethod
    def encode(uuid_str):
        num = int(uuid_str.replace('-', ''), 16)
        return UUIDShortener._base62_encode(num)

    @staticmethod
    def decode(short_str):
        num = UUIDShortener._base62_decode(short_str)
        uuid_str = format(num, 'x').zfill(32)
        return f'{uuid_str[:8]}-{uuid_str[8:12]}-{uuid_str[12:16]}-{uuid_str[16:20]}-{uuid_str[20:]}'

    @staticmethod
    def _base62_encode(num):
        if num == 0:
            return UUIDShortener.alphabet[0]
        base62 = []
        base = len(UUIDShortener.alphabet)
        while num:
            num, rem = divmod(num, base)
            base62.append(UUIDShortener.alphabet[rem])
        return ''.join(reversed(base62))

    @staticmethod
    def _base62_decode(str):
        base = len(UUIDShortener.alphabet)
        strlen = len(str)
        num = 0
        idx = 0
        for char in str:
            power = (strlen - (idx + 1))
            num += UUIDShortener.alphabet.index(char) * (base ** power)
            idx += 1
        return num

# Example usage
if __name__ == "__main__":
    original_uuid = str(uuid.uuid4())
    print(f"Original UUID: {original_uuid}")

    short_uuid = UUIDShortener.encode(original_uuid)
    print(f"Shortened UUID: {short_uuid}")

    decoded_uuid = UUIDShortener.decode(short_uuid)
    print(f"Decoded UUID: {decoded_uuid}")

